@@ -34,9 +34,7 @@ Example Usage
     ):
         """Make the bot repeat what you say""" # description of command
         # respond to the interaction, must be done within 3 seconds
-        await ctx.respond(message, # string (or str()able) message
-            # sends a response message immediately
-            rtype=slash.InteractionResponseType.ChannelMessageWithSource)
+        await ctx.respond(message) # string (or str()able) message
 
     client.run(token)
 
@@ -81,7 +79,7 @@ __all__ = [
     'SlashBot'
 ]
 
-__version__ = '0.5.0'
+__version__ = '0.6.1'
 
 class SlashWarning(UserWarning):
     """Watch out, this may cause problems down the line."""
@@ -222,6 +220,16 @@ class Context(discord.Object, _AsyncInit):
     client: SlashBot
     webhook: Optional[discord.Webhook]
 
+    @property
+    def bot(self) -> SlashBot:
+        """The bot. Alias for self.client."""
+        return self.client
+
+    @bot.setter
+    def bot(self, value: SlashBot):
+        """The bot. Alias for self.client."""
+        self.client = value
+
     async def __init__(self, client: SlashBot, cmd: Command, event: dict):
         self.client = client
         self.command = cmd
@@ -411,7 +419,8 @@ class Context(discord.Object, _AsyncInit):
 
     async def respond(
         self, content='', *, embed=None, embeds=None, allowed_mentions=None,
-        flags=None, rtype=InteractionResponseType.ChannelMessageWithSource
+        file=None, ephemeral=False, deferred=False, flags=None,
+        rtype=InteractionResponseType.ChannelMessageWithSource
     ):
         """Respond to the interaction. If called again, edits the response.
 
@@ -425,11 +434,21 @@ class Context(discord.Object, _AsyncInit):
             Up to 10 embeds (any more will be silently discarded)
         allowed_mentions: :class:`discord.AllowedMentions`
             Mirrors normal ``allowed_mentions`` in Messageable.send
+        file: :class:`discord.File`
+            Mirrors normal ``file`` in Messageable.send
+        ephemeral: :class:`bool`
+            Shortcut to setting ``flags=MessageFlags.EPHEMERAL``.
+            If other flags are present, they are preserved.
+        deferred: :class:`bool`
+            Shortcut to setting ``rtype=DeferredChannelMessageWithSource``.
+            Overrides ``rtype`` unconditionally if ``True``.
         flags: Union[int, :class:`MessageFlags`]
             Message flags, ORed together
         rtype: :class:`InteractionResponseType`
             The type of response to send. See that class's documentation.
         """
+        if deferred:
+            rtype = InteractionResponseType.DeferredChannelMessageWithSource
         if rtype in {
             InteractionResponseType.Acknowledge,
             InteractionResponseType.ChannelMessage,
@@ -473,6 +492,8 @@ class Context(discord.Object, _AsyncInit):
                 data['data']['embeds'] = embeds
             if mentions is not None:
                 data['data']['allowed_mentions'] = mentions.to_dict()
+            if ephemeral:
+                flags = (flags or 0) | MessageFlags.EPHEMERAL
             if flags:
                 data.setdefault('data', {})['flags'] = int(flags)
             path = f"/interactions/{self.id}/{self.token}/callback"
@@ -481,7 +502,19 @@ class Context(discord.Object, _AsyncInit):
             self.webhook = discord.Webhook.partial(
                 id=self.client.app_info.id, token=self.token, adapter=
                 discord.AsyncWebhookAdapter(self.client.http._HTTPClient__session))
-        await self.client.http.request(route, json=data)
+        if isinstance(file, discord.File):
+            form = []
+            form.append({'name': 'payload_json',
+                         'value': discord.utils.to_json(data)})
+            form.append({
+                'name': 'file',
+                'value': file.fp,
+                'filename': file.filename,
+                'content_type': 'application/octet-stream'
+            })
+            await self.client.http.request(route, form=form, files=[file])
+        else:
+            await self.client.http.request(route, json=data)
 
     async def delete(self):
         """Delete the original interaction response message."""
@@ -633,7 +666,7 @@ class Command(discord.Object):
         self.description = kwargs.pop('description', coro.__doc__)
         if not self.description:
             raise ValueError(f'Please specify a description for {self.name!r}')
-        self.guild_id = kwargs.pop('guild', None)
+        self.guild_id = kwargs.pop('guild_id', kwargs.pop('guild', None))
         if self.guild_id is not None:
             self.guild_id = int(self.guild_id)
         self.parent = kwargs.pop('parent', None)
@@ -726,6 +759,7 @@ class Command(discord.Object):
         Can be used as a decorator.
         """
         self._check = coro
+        return coro
 
     async def can_run(self, ctx):
         parents = []  # highest level parent last
@@ -932,10 +966,11 @@ class SlashBot(commands.Bot):
                  f'by ID {event["data"]["id"]}, falling back to '
                  'name + guild search', SlashWarning)
             cmd = discord.utils.get(
-                self.slash, name=event['data']['name'], guild_id=event['guild_id'])
+                self.slash, name=event['data']['name'],
+                guild_id=int(event['guild_id'] or 0) or None)
         if cmd is None:
             warn(f'No command {event["data"]["name"]!r} found '
-                 f'by name and guild ID {event["guild_id"]}, '
+                 f'by name and guild ID {event["guild_id"]!r}, '
                  'falling back to name-only search', SlashWarning)
             cmd = discord.utils.get(
                 self.slash, name=event['data']['name'])
@@ -955,13 +990,20 @@ class SlashBot(commands.Bot):
             except commands.CommandInvokeError as exc2:
                 self.dispatch('command_error', ctx, exc2)
 
-    async def register_commands(self):
+    async def register_commands(self, guild_id: int = None):
+        """Update commands on the API.
+
+        guild_id: :class:`int`
+            Only update commands specific to this guild.
+        """
         app_info = await self.application_info()
         global_path = f"/applications/{app_info.id}/commands"
         guild_path = f"/applications/{app_info.id}/guilds/{{0}}/commands"
         guilds = {}
         for cmd in self.slash:
             cmd.guild_id = cmd.guild_id or self.debug_guild
+            if guild_id and cmd.guild_id != guild_id:
+                continue
             guilds.setdefault(cmd.guild_id, {})[cmd.name] = cmd
         state = {
             'POST': {},
